@@ -4,6 +4,7 @@ Most users will not need to interact with this module."""
 from abc import abstractmethod
 from inspect import signature
 from operator import itemgetter
+from logging import getLogger
 from typing import Union, Dict, List, Any
 
 import numpy as np
@@ -16,6 +17,8 @@ from megnet.data import local_env
 from megnet.utils.data import get_graphs_within_cutoff
 from megnet.utils.general import expand_1st, to_list
 
+logger = getLogger(__name__)
+
 
 class Converter(MSONable):
     """
@@ -108,7 +111,7 @@ class StructureGraph(MSONable):
                 bonds.append(neighbor["weight"])
         atoms = self.get_atom_features(structure)
         if np.size(np.unique(index1)) < len(atoms):
-            raise RuntimeError("Isolated atoms found in the structure")
+            logger.warning("Isolated atoms found in the structure")
 
         return {"atom": atoms, "bond": bonds, "state": state_attributes, "index1": index1, "index2": index2}
 
@@ -245,8 +248,12 @@ class StructureGraphFixedRadius(StructureGraph):
         atoms = self.get_atom_features(structure)
         index1, index2, _, bonds = get_graphs_within_cutoff(structure, self.nn_strategy.cutoff)
 
+        if len(index1) == 0:
+            raise RuntimeError("The cutoff is too small, resulting in " "material graph with no bonds")
+
         if np.size(np.unique(index1)) < len(atoms):
-            raise RuntimeError("Isolated atoms found in the structure")
+            logger.warning("Isolated atoms found in the structure. The " "cutoff radius might be small")
+
         return {"atom": atoms, "bond": bonds, "state": state_attributes, "index1": index1, "index2": index2}
 
     @classmethod
@@ -417,6 +424,7 @@ class BaseGraphBatchGenerator(Sequence):
             gbond += [i] * len(j)
 
         # assemble atom features together
+        n_atoms = [len(i) for i in feature_list_temp]
         feature_list_temp = np.concatenate(feature_list_temp, axis=0)
         feature_list_temp = self.process_atom_feature(feature_list_temp)
 
@@ -432,10 +440,12 @@ class BaseGraphBatchGenerator(Sequence):
         index1 = []
         index2 = []
         offset_ind = 0
-        for ind1, ind2 in zip(index1_temp, index2_temp):
+        for ind1, ind2, n_atom in zip(index1_temp, index2_temp, n_atoms):
             index1 += [i + offset_ind for i in ind1]
             index2 += [i + offset_ind for i in ind2]
-            offset_ind += max(ind1) + 1
+            # offset_ind += max(ind1) + 1
+            offset_ind += n_atom
+
         # Compile the inputs in needed order
         inputs = (
             expand_1st(feature_list_temp),
